@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_alpha.c,v 1.27 2007/06/07 15:36:24 debug Exp $
+ *  $Id: cpu_alpha.c,v 1.29.2.1 2008/01/18 19:12:24 debug Exp $
  *
  *  Alpha CPU emulation.
  *
@@ -47,15 +47,12 @@
 #include "misc.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 
 #define	DYNTRANS_8K
 #define	DYNTRANS_PAGESIZE	8192
 #include "tmp_alpha_head.c"
 
 
-extern int native_code_translation_enabled;
-
 /*  Alpha symbolic register names:  */
 static char *alpha_regname[N_ALPHA_REGS] = ALPHA_REG_NAMES; 
 
@@ -133,10 +130,6 @@ int alpha_cpu_new(struct cpu *cpu, struct memory *mem,
 		interrupt_handler_register(&template);
 	}
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    alpha_timer_sample_tick, cpu);
-
 	return 1;
 }
 
@@ -679,7 +672,7 @@ int alpha_cpu_disassemble_instr(struct cpu *cpu, unsigned char *ib,
 #define MEMORY_RW       alpha_userland_memory_rw
 #define MEM_ALPHA
 #define MEM_USERLAND
-#include "../memory_rw.c"
+#include "memory_rw.c"
 #undef MEM_USERLAND
 #undef MEM_ALPHA
 #undef MEMORY_RW
