@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_arm.c,v 1.71 2007/06/15 00:41:21 debug Exp $
+ *  $Id: cpu_arm.c,v 1.72.2.1 2008/01/18 19:12:24 debug Exp $
  *
  *  ARM CPU emulation.
  *
@@ -50,15 +50,12 @@
 #include "of.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 #include "useremul.h"
 
 #define DYNTRANS_32
 #include "tmp_arm_head.c"
 
 
-extern int native_code_translation_enabled;
-
 /*  ARM symbolic register names and condition strings:  */
 static char *arm_regname[N_ARM_REGS] = ARM_REG_NAMES;
 static char *arm_condition_string[16] = ARM_CONDITION_STRINGS;
@@ -195,10 +192,6 @@ int arm_cpu_new(struct cpu *cpu, struct memory *mem,
 		/*  FIQ: TODO  */
         }
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    arm_timer_sample_tick, cpu);
-
 	return 1;
 }
 
