@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_arm_instr.c,v 1.74 2007/06/14 04:53:46 debug Exp $
+ *  $Id: cpu_arm_instr.c,v 1.77.2.1 2008/01/18 19:12:24 debug Exp $
  *
  *  ARM instructions.
  *
@@ -1569,6 +1569,8 @@ X(netbsd_idle)
 	}
 
 	if (rZ == 0) {
+		static int x = 0;
+
 		/*  Synch the program counter.  */
 		uint32_t low_pc = ((size_t)ic - (size_t)
 		    cpu->cd.arm.cur_ic_page) / sizeof(struct arm_instr_call);
@@ -1578,10 +1580,12 @@ X(netbsd_idle)
 
 		/*  Quasi-idle for a while:  */
 		cpu->has_been_idling = 1;
-	        if (cpu->machine->ncpus == 1)
+	        if (cpu->machine->ncpus == 1 && (++x) == 100) {
 			usleep(50);
-		cpu->n_translated_instrs += N_SAFE_DYNTRANS_LIMIT;
+			x = 0;
+		}
 
+		cpu->n_translated_instrs += N_SAFE_DYNTRANS_LIMIT / 6;
 		cpu->cd.arm.next_ic = &nothing_call;
 		return;
 	}
@@ -2529,6 +2533,7 @@ X(to_be_translated)
 
 	/*  Read the instruction word from memory:  */
 	page = cpu->cd.arm.host_load[addr >> 12];
+
 	if (page != NULL) {
 		/*  fatal("TRANSLATION HIT! 0x%08x\n", addr);  */
 		memcpy(ib, page + (addr & 0xfff), sizeof(ib));
@@ -2923,17 +2928,13 @@ X(to_be_translated)
 				/*  ic->f = cond_instr(mov);  */
 				ic->f = arm_dpi_instr[condition_code + 16*0xd];
 				ic->arg[2] = (size_t)(&cpu->cd.arm.r[rd]);
-				p = cpu->cd.arm.host_load[a >> 12];
+				p = page;
 				if (p != NULL) {
 					memcpy(c, p + (a & 0xfff), len);
 				} else {
-					if (!cpu->memory_rw(cpu, cpu->mem, a,
-					    c, len, MEM_READ, CACHE_DATA)) {
-						if (!cpu->translation_readahead)
-							fatal("read failed X:"
-							    " TODO\n");
-						goto bad;
-					}
+					fatal("Hm? Internal error in "
+					    "cpu_arm_instr.c!\n");
+					goto bad;
 				}
 				if (cpu->byte_order == EMUL_LITTLE_ENDIAN)
 					x = c[0] + (c[1]<<8) +
