@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,9 +25,14 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_dyntrans.c,v 1.165 2007/06/15 21:43:53 debug Exp $
+ *  $Id: cpu_dyntrans.c,v 1.187.2.1 2008/01/18 19:12:25 debug Exp $
  *
  *  Common dyntrans routines. Included from cpu_*.c.
+ *
+ *  Note: This might be a bit hard to follow, if you are reading this source
+ *  code for the first time. It is basically a hack to implement "templates"
+ *  with normal C code, by using suitable defines/macros, and then including
+ *  this file.
  */
 
 
@@ -45,7 +50,7 @@ static void gather_statistics(struct cpu *cpu)
 	int low_pc = ((size_t)cpu->cd.DYNTRANS_ARCH.next_ic - (size_t)
 	    cpu->cd.DYNTRANS_ARCH.cur_ic_page) / sizeof(struct DYNTRANS_IC);
 
-	if (cpu->machine->statistics_file == NULL) {
+	if (cpu->machine->statistics.file == NULL) {
 		fatal("statistics gathering with no filename set is"
 		    " meaningless\n");
 		return;
@@ -57,7 +62,7 @@ static void gather_statistics(struct cpu *cpu)
 
 	buf[0] = '\0';
 
-	while ((ch = cpu->machine->statistics_fields[i]) != '\0') {
+	while ((ch = cpu->machine->statistics.fields[i]) != '\0') {
 		if (i != 0)
 			strlcat(buf, " ", sizeof(buf));
 
@@ -98,7 +103,7 @@ static void gather_statistics(struct cpu *cpu)
 		i++;
 	}
 
-	fprintf(cpu->machine->statistics_file, "%s\n", buf);
+	fprintf(cpu->machine->statistics.file, "%s\n", buf);
 }
 
 
@@ -161,7 +166,7 @@ static void gather_statistics(struct cpu *cpu)
 
 
 
-#ifdef	DYNTRANS_RUN_INSTR
+#ifdef	DYNTRANS_RUN_INSTR_DEF
 /*
  *  XXX_run_instr():
  *
@@ -171,7 +176,7 @@ static void gather_statistics(struct cpu *cpu)
  *  Return value is the number of instructions executed during this call,
  *  0 if no instructions were executed.
  */
-int DYNTRANS_RUN_INSTR(struct cpu *cpu)
+int DYNTRANS_RUN_INSTR_DEF(struct cpu *cpu)
 {
 	MODE_uint_t cached_pc;
 	int low_pc, n_instrs;
@@ -199,6 +204,11 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 	if (cpu->cd.arm.irq_asserted && !(cpu->cd.arm.cpsr & ARM_FLAG_I))
 		arm_exception(cpu, ARM_EXCEPTION_IRQ);
 #endif
+#ifdef DYNTRANS_M88K
+	if (cpu->cd.m88k.irq_asserted &&
+	    !(cpu->cd.m88k.cr[M88K_CR_PSR] & M88K_PSR_IND))
+		m88k_exception(cpu, M88K_EXCEPTION_INTERRUPT, 0);
+#endif
 #ifdef DYNTRANS_MIPS
 	{
 		int enabled, mask;
@@ -294,14 +304,14 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 			}
 		}
 
-		if (cpu->machine->statistics_enabled)
+		if (cpu->machine->statistics.enabled)
 			S;
 
 		/*  Execute just one instruction:  */
 		I;
 
 		n_instrs = 1;
-	} else if (cpu->machine->statistics_enabled) {
+	} else if (cpu->machine->statistics.enabled) {
 		/*  Gather statistics while executing multiple instructions:  */
 		n_instrs = 0;
 		for (;;) {
@@ -325,7 +335,6 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 		 *  (This is the core dyntrans loop.)
 		 */
 		n_instrs = 0;
-		cpu->sampling = 1;
 
 		for (;;) {
 			struct DYNTRANS_IC *ic;
@@ -350,8 +359,6 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 			if (cpu->n_translated_instrs >= N_SAFE_DYNTRANS_LIMIT)
 				break;
 		}
-
-		cpu->sampling = 0;
 	}
 
 	n_instrs += cpu->n_translated_instrs;
@@ -423,16 +430,6 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 
 	cpu->ninstrs += n_instrs;
 
-	/*
-	 *  Check if there are enough samples to decide whether or not to
-	 *  perform native code generation:
-	 */
-	if (cpu->sampling_curindex == N_PADDR_SAMPLES) {
-		/*  TODO: Check against known blocks, etc.  */
-
-		cpu->sampling_curindex = 0;
-	}
-
 	/*  Return the nr of instructions executed:  */
 	return n_instrs;
 }
@@ -440,7 +437,7 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
 
 
 
-#ifdef DYNTRANS_FUNCTION_TRACE
+#ifdef DYNTRANS_FUNCTION_TRACE_DEF
 /*
  *  XXX_cpu_functioncall_trace():
  *
@@ -448,7 +445,7 @@ int DYNTRANS_RUN_INSTR(struct cpu *cpu)
  *  like    <f()>  or  <0x1234()>   on a function call. It is up to this
  *  function to print the arguments passed.
  */
-void DYNTRANS_FUNCTION_TRACE(struct cpu *cpu, uint64_t f, int n_args)
+void DYNTRANS_FUNCTION_TRACE_DEF(struct cpu *cpu, uint64_t f, int n_args)
 {
 	int show_symbolic_function_name = 1;
         char strbuf[50];
@@ -504,6 +501,9 @@ void DYNTRANS_FUNCTION_TRACE(struct cpu *cpu, uint64_t f, int n_args)
 #ifdef DYNTRANS_MIPS
 		    gpr[MIPS_GPR_A0
 #endif
+#ifdef DYNTRANS_M32R
+		    r[0		/*  r0..r3?  */
+#endif
 #ifdef DYNTRANS_M88K
 		    r[2		/*  r2..r9  */
 #endif
@@ -543,69 +543,18 @@ void DYNTRANS_FUNCTION_TRACE(struct cpu *cpu, uint64_t f, int n_args)
 	if (print_dots)
 		fatal(",..");
 }
-#endif
+#endif	/*  DYNTRANS_FUNCTION_TRACE_DEF  */
 
 
 
-#ifdef DYNTRANS_TIMER_SAMPLE_TICK
-/*
- *  XXX_timer_sample_tick():
- *
- *  Gathers statistics about which translation blocks are being executed.
- *  This can then be used to calculate if it is worth the effort to perform
- *  native code generation (which is assumed to have a large overhead, but
- *  will result in faster code).
- */
-void DYNTRANS_TIMER_SAMPLE_TICK(struct timer *timer, void *extra)
-{
-	struct cpu *cpu = extra;
-	struct DYNTRANS_IC *next_ic;
-	size_t low_pc;
-	uint64_t paddr;
-
-	/*
-	 *  Don't sample if:
-	 *
-	 *  1)  Sampling is not enabled. It should only be enabled during
-	 *      the core dyntrans loop.
-	 *  2)  Enough samples have already been gathered.
-	 */
-
-	if (!cpu->sampling || cpu->sampling_curindex == N_PADDR_SAMPLES)
-		return;
-
-	/*  Get the physical address of the program counter:  */
-
-	next_ic = cpu->cd.DYNTRANS_ARCH.next_ic;
-	low_pc = ((size_t)next_ic - (size_t)cpu->cd.DYNTRANS_ARCH.cur_ic_page)
-	    / sizeof(struct DYNTRANS_IC);
-
-	/*  Not possible to represent as a physical address? Then abort.  */
-	if (low_pc > DYNTRANS_IC_ENTRIES_PER_PAGE)
-		return;
-
-	cpu->cd.DYNTRANS_ARCH.cur_physpage = (void *)
-	    cpu->cd.DYNTRANS_ARCH.cur_ic_page;
-	paddr = cpu->cd.DYNTRANS_ARCH.cur_physpage->physaddr;
-	paddr &= ~((DYNTRANS_IC_ENTRIES_PER_PAGE-1) <<
-	    DYNTRANS_INSTR_ALIGNMENT_SHIFT);
-	paddr += low_pc << DYNTRANS_INSTR_ALIGNMENT_SHIFT;
-
-	/*  ... and finally add the sample to the sampling array:  */
-	cpu->sampling_paddr[cpu->sampling_curindex ++] = paddr;
-}
-#endif	/*  DYNTRANS_TIMER_SAMPLE_TICK  */
-
-
-
-#ifdef DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE
+#ifdef DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE_DEF
 /*
  *  XXX_tc_allocate_default_page():
  *
  *  Create a default page (with just pointers to instr(to_be_translated)
  *  at cpu->translation_cache_cur_ofs.
  */
-static void DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE(struct cpu *cpu,
+static void DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE_DEF(struct cpu *cpu,
 	uint64_t physaddr)
 { 
 	struct DYNTRANS_TC_PHYSPAGE *ppp;
@@ -622,10 +571,10 @@ static void DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE(struct cpu *cpu,
 	cpu->translation_cache_cur_ofs += sizeof(struct DYNTRANS_TC_PHYSPAGE);
 
 	cpu->translation_cache_cur_ofs --;
-	cpu->translation_cache_cur_ofs |= 127;
+	cpu->translation_cache_cur_ofs |= 63;
 	cpu->translation_cache_cur_ofs ++;
 }
-#endif	/*  DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE  */
+#endif	/*  DYNTRANS_TC_ALLOCATE_DEFAULT_PAGE_DEF  */
 
 
 
@@ -838,7 +787,7 @@ void DYNTRANS_PC_TO_POINTERS_GENERIC(struct cpu *cpu)
 	 *  as non-writable. If there are already translations, then it
 	 *  should already have been marked as non-writable.
 	 */
-	if (ppp->translations == 0) {
+	if (ppp->translations_bitmap == 0) {
 		cpu->invalidate_translation_caches(cpu, physaddr,
 		    JUST_MARK_AS_NON_WRITABLE | INVALIDATE_PADDR);
 	}
@@ -928,6 +877,13 @@ static void instr32(to_be_translated)(struct cpu *, struct DYNTRANS_IC *);
 static void instr32(end_of_page)(struct cpu *,struct DYNTRANS_IC *);
 #endif
 
+#ifdef DYNTRANS_DUALMODE_32
+#define TO_BE_TRANSLATED    ( cpu->is_32bit? instr32(to_be_translated) : \
+			      instr(to_be_translated) )
+#else
+#define TO_BE_TRANSLATED    ( instr(to_be_translated) )
+#endif
+
 #ifdef DYNTRANS_DELAYSLOT
 static void instr(end_of_page2)(struct cpu *,struct DYNTRANS_IC *);
 #ifdef DYNTRANS_DUALMODE_32
@@ -954,16 +910,12 @@ void DYNTRANS_INIT_TABLES(struct cpu *cpu)
 	CHECK_ALLOCATION(ppp = malloc(sizeof(struct DYNTRANS_TC_PHYSPAGE)));
 
 	ppp->next_ofs = 0;
-	ppp->translations = 0;
+	ppp->translations_bitmap = 0;
+	ppp->translation_ranges_ofs = 0;
 	/*  ppp->physaddr is filled in by the page allocator  */
 
-	for (i=0; i<DYNTRANS_IC_ENTRIES_PER_PAGE; i++) {
-		ppp->ics[i].f =
-#ifdef DYNTRANS_DUALMODE_32
-		    cpu->is_32bit? instr32(to_be_translated) :
-#endif
-		    instr(to_be_translated);
-	}
+	for (i=0; i<DYNTRANS_IC_ENTRIES_PER_PAGE; i++)
+		ppp->ics[i].f = TO_BE_TRANSLATED;
 
 	/*  End-of-page:  */
 	ppp->ics[DYNTRANS_IC_ENTRIES_PER_PAGE + 0].f =
@@ -1343,9 +1295,9 @@ void DYNTRANS_INVALIDATE_TC_CODE(struct cpu *cpu, uint64_t addr, int flags)
 		 *  it might be faster since we don't risk wasting cache
 		 *  memory as quickly (which would force unnecessary Restarts).
 		 */
-		if (ppp != NULL && ppp->translations != 0) {
-			uint32_t x = ppp->translations;	/*  TODO:
-				urk Should be same type as ppp->translations */
+		if (ppp != NULL && ppp->translations_bitmap != 0) {
+			uint32_t x = ppp->translations_bitmap;	/*  TODO:
+				urk Should be same type as the bitmap */
 			int i, j, n, m;
 			n = 8 * sizeof(x);
 			m = DYNTRANS_IC_ENTRIES_PER_PAGE / n;
@@ -1354,17 +1306,23 @@ void DYNTRANS_INVALIDATE_TC_CODE(struct cpu *cpu, uint64_t addr, int flags)
 				if (x & 1) {
 					for (j=0; j<m; j++)
 						ppp->ics[i*m + j].f =
-#ifdef DYNTRANS_DUALMODE_32
-						    cpu->is_32bit?
-						    instr32(to_be_translated) :
-#endif
-						    instr(to_be_translated);
+						    TO_BE_TRANSLATED;
 				}
 
 				x >>= 1;
 			}
 
-			ppp->translations = 0;
+			ppp->translations_bitmap = 0;
+
+			/*  Clear the list of translatable ranges:  */
+			if (ppp->translation_ranges_ofs != 0) {
+				struct physpage_ranges *physpage_ranges =
+				    (struct physpage_ranges *)
+				    (cpu->translation_cache +
+				    ppp->translation_ranges_ofs);
+				physpage_ranges->next_ofs = 0;
+				physpage_ranges->n_entries_used = 0;
+			}
 		}
 #endif
 	}
@@ -1651,7 +1609,6 @@ void DYNTRANS_UPDATE_TRANSLATION_TABLE(struct cpu *cpu, uint64_t vaddr_page,
 				l3->host_store[x3] = NULL;
 		} else {
 			/*  Change the entire physical/host mapping:  */
-printf("HOST LOAD 2 set to %p\n", host_page);
 			l3->host_load[x3] = host_page;
 			l3->host_store[x3] = writeflag? host_page : NULL;
 			l3->phys_addr[x3] = paddr_page;
@@ -1746,12 +1703,15 @@ cpu->cd.DYNTRANS_ARCH.vph_tlb_entry[r].valid);
 	{
 		int x = addr & (DYNTRANS_PAGESIZE - 1);
 		int addr_per_translation_range = DYNTRANS_PAGESIZE / (8 *
-		    sizeof(cpu->cd.DYNTRANS_ARCH.cur_physpage->translations));
+		    sizeof(cpu->cd.DYNTRANS_ARCH.cur_physpage->
+		    translations_bitmap));
 		x /= addr_per_translation_range;
 
-		cpu->cd.DYNTRANS_ARCH.cur_physpage->translations |= (1 << x);
+		cpu->cd.DYNTRANS_ARCH.cur_physpage->
+		    translations_bitmap |= (1 << x);
 	}
 
+
 	/*
 	 *  Now it is time to check for combinations of instructions that can
 	 *  be converted into a single function call.
@@ -1774,11 +1734,7 @@ cpu->cd.DYNTRANS_ARCH.vph_tlb_entry[r].valid);
 	cpu->cd.DYNTRANS_ARCH.combination_check = NULL;
 
 	/*  An additional check, to catch some bugs:  */
-	if (ic->f == (
-#ifdef DYNTRANS_DUALMODE_32
-	    cpu->is_32bit? instr32(to_be_translated) :
-#endif
-	    instr(to_be_translated))) {
+	if (ic->f == TO_BE_TRANSLATED) {
 		fatal("INTERNAL ERROR: ic->f not set!\n");
 		goto bad;
 	}
@@ -1787,7 +1743,10 @@ cpu->cd.DYNTRANS_ARCH.vph_tlb_entry[r].valid);
 		goto bad;
 	}
 
-	/*  ... and finally execute the translated instruction:  */
+
+	/*
+	 *  ... and finally execute the translated instruction:
+	 */
 
 	/*  (Except when doing read-ahead!)  */
 	if (cpu->translation_readahead)
@@ -1805,21 +1764,15 @@ cpu->cd.DYNTRANS_ARCH.vph_tlb_entry[r].valid);
 	    ) {
 		single_step_breakpoint = 0;
 		ic->f(cpu, ic);
-		ic->f =
-#ifdef DYNTRANS_DUALMODE_32
-		    cpu->is_32bit? instr32(to_be_translated) :
-#endif
-		    instr(to_be_translated);
-
+		ic->f = TO_BE_TRANSLATED;
 		return;
 	}
 
 	/*  Translation read-ahead:  */
 	if (!single_step && !cpu->machine->instruction_trace) {
-		/*  Do readahead:  */
-		int i = 1;
-		uint64_t pagenr = DYNTRANS_ADDR_TO_PAGENR(cpu->pc);
 		uint64_t baseaddr = cpu->pc;
+		uint64_t pagenr = DYNTRANS_ADDR_TO_PAGENR(baseaddr);
+		int i = 1;
 
 		cpu->translation_readahead = MAX_DYNTRANS_READAHEAD;
 
@@ -1830,11 +1783,7 @@ cpu->cd.DYNTRANS_ARCH.vph_tlb_entry[r].valid);
 			    struct DYNTRANS_IC *) = ic[i].f;
 
 			/*  Already translated? Then abort:  */
-			if (old_f != (
-#ifdef DYNTRANS_DUALMODE_32
-			    cpu->is_32bit? instr32(to_be_translated) :
-#endif
-			    instr(to_be_translated)))
+			if (old_f != TO_BE_TRANSLATED)
 				break;
 
 			/*  Translate the instruction:  */
@@ -1869,11 +1818,7 @@ bad:	/*
 	 */
 
 	/*  Clear the translation, in case it was "half-way" done:  */
-	ic->f =
-#ifdef DYNTRANS_DUALMODE_32
-	    cpu->is_32bit? instr32(to_be_translated) :
-#endif
-	    instr(to_be_translated);
+	ic->f = TO_BE_TRANSLATED;
 
 	if (cpu->translation_readahead)
 		return;
@@ -1881,13 +1826,12 @@ bad:	/*
 	quiet_mode = 0;
 	fatal("to_be_translated(): TODO: unimplemented instruction");
 
-	if (cpu->machine->instruction_trace)
-#ifdef MODE32
-		fatal(" at 0x%"PRIx32"\n", (uint32_t)cpu->pc);
-#else
-		fatal(" at 0x%"PRIx64"\n", (uint64_t)cpu->pc);
-#endif
-	else {
+	if (cpu->machine->instruction_trace) {
+		if (cpu->is_32bit)
+			fatal(" at 0x%"PRIx32"\n", (uint32_t)cpu->pc);
+		else
+			fatal(" at 0x%"PRIx64"\n", (uint64_t)cpu->pc);
+	} else {
 		fatal(":\n");
 		DISASSEMBLE(cpu, ib, 1, 0);
 	}
