@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_m88k.c,v 1.38 2007/06/07 15:36:24 debug Exp $
+ *  $Id: cpu_m88k.c,v 1.39.2.1 2008/01/18 19:12:25 debug Exp $
  *
  *  Motorola M881x0 CPU emulation.
  */
@@ -43,7 +43,6 @@
 #include "mvmeprom.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 
 #include "m8820x_pte.h"
 #include "m88k_dmt.h"
@@ -53,8 +52,6 @@
 #include "tmp_m88k_head.c"
 
 
-extern int native_code_translation_enabled;
-
 void m88k_pc_to_pointers(struct cpu *);
 
 static char *memop[4] = { ".d", "", ".h", ".b" };
@@ -183,10 +180,6 @@ int m88k_cpu_new(struct cpu *cpu, struct memory *mem,
 	/*  Initial stack pointer:  */
 	cpu->cd.m88k.r[31] = 1048576 * cpu->machine->physical_ram_in_mb - 1024;
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    m88k_timer_sample_tick, cpu);
-
 	return 1;
 }
 
