@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2003-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_mips.c,v 1.83 2007/06/15 18:07:08 debug Exp $
+ *  $Id: cpu_mips.c,v 1.84.2.1 2008/01/18 19:12:25 debug Exp $
  *
  *  MIPS core CPU emulation.
  */
@@ -52,11 +52,8 @@
 #include "opcodes_mips.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 
 
-extern int native_code_translation_enabled;
-
 static char *exception_names[] = EXCEPTION_NAMES;
 
 static char *hi6_names[] = HI6_NAMES;
@@ -337,10 +334,6 @@ int mips_cpu_new(struct cpu *cpu, struct memory *mem, struct machine *machine,
 		CPU_SETTINGS_ADD_REGISTER64(cop0_names[i],
 		    cpu->cd.mips.coproc[0]->reg[i]);
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    mips_timer_sample_tick, cpu);
-
 	return 1;
 }
 
