@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_sparc.c,v 1.46 2007/06/07 15:36:24 debug Exp $
+ *  $Id: cpu_sparc.c,v 1.47.2.1 2008/01/18 19:12:26 debug Exp $
  *
  *  SPARC CPU emulation.
  */
@@ -41,7 +41,6 @@
 #include "misc.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 
 
 #define	DYNTRANS_DUALMODE_32
@@ -49,8 +48,6 @@
 #include "tmp_sparc_head.c"
 
 
-extern int native_code_translation_enabled;
-
 static char *sparc_regnames[N_SPARC_REG] = SPARC_REG_NAMES;
 static char *sparc_pregnames[N_SPARC_PREG] = SPARC_PREG_NAMES;
 static char *sparc_regbranch_names[N_SPARC_REGBRANCH_TYPES] =
@@ -171,10 +168,6 @@ int sparc_cpu_new(struct cpu *cpu, struct memory *mem, struct machine *machine,
 		    cpu->cd.sparc.r[i]);
 	/*  TODO: Handler for writes to the zero register!  */
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    sparc_timer_sample_tick, cpu);
-
 	return 1;
 }
 
