@@ -2,7 +2,7 @@
 #define	CPU_ARM_H
 
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,14 +28,13 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_arm.h,v 1.74 2007/06/14 04:53:14 debug Exp $
+ *  $Id: cpu_arm.h,v 1.75.2.1 2008/01/18 19:12:31 debug Exp $
  */
 
 #include "misc.h"
 #include "interrupt.h"
 
 struct cpu_family;
-struct timer;
 
 /*  ARM CPU types:  */
 struct arm_cpu_type_def {
@@ -290,7 +289,6 @@ void arm_translation_table_set_l1_b(struct cpu *cpu, uint32_t vaddr,
 	uint32_t paddr);
 void arm_exception(struct cpu *, int);
 int arm_run_instr(struct cpu *cpu);
-void arm_timer_sample_tick(struct timer *, void *);
 void arm_update_translation_table(struct cpu *cpu, uint64_t vaddr_page,
 	unsigned char *host_page, int writeflag, uint64_t paddr_page);
 void arm_invalidate_translation_caches(struct cpu *cpu, uint64_t, int);
