@@ -2,7 +2,7 @@
 #define	CPU_SH_H
 
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,10 +28,14 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_sh.h,v 1.46 2007/06/07 15:36:25 debug Exp $
+ *  $Id: cpu_sh.h,v 1.50.2.1 2008/01/18 19:12:31 debug Exp $
  *
- *  Note: Many things here are SH4-specific, so it probably doesn't work
- *        for SH3 emulation.
+ *  Note 1: Many things here are SH4-specific, so it probably doesn't work
+ *          for SH3 emulation.
+ *
+ *  Note 2: The SuperH emulation in GXemul does not include SH5/SH64 at
+ *          this time. There doesn't seem to be that much interesting code
+ *          to run in the emulator for SH5. :-/
  */
 
 #include "interrupt.h"
@@ -40,7 +44,6 @@
 
 
 struct cpu_family;
-struct timer;
 
 
 /*  SH CPU types:  */
@@ -61,14 +64,9 @@ struct sh_cpu_type_def {
 	{ NULL,       0, 0, 0,              0	                 }  }
 
 
-/*
- *  TODO: Figure out how to nicely support multiple instruction encodings!
- *  For now, I'm reverting this to SH4. SH5 will have to wait until later.
- */
-
-#define	SH_N_IC_ARGS			2	/*  3 for SH5/SH64  */
-#define	SH_INSTR_ALIGNMENT_SHIFT	1	/*  2 for SH5/SH64  */
-#define	SH_IC_ENTRIES_SHIFT		11	/*  10 for SH5/SH64  */
+#define	SH_N_IC_ARGS			2
+#define	SH_INSTR_ALIGNMENT_SHIFT	1
+#define	SH_IC_ENTRIES_SHIFT		11
 #define	SH_IC_ENTRIES_PER_PAGE		(1 << SH_IC_ENTRIES_SHIFT)
 #define	SH_PC_TO_IC_ENTRY(a)		(((a)>>SH_INSTR_ALIGNMENT_SHIFT) \
 					& (SH_IC_ENTRIES_PER_PAGE-1))
@@ -87,6 +85,8 @@ DYNTRANS_MISC_DECLARATIONS(sh,SH,uint32_t)
 #define	SH_N_ITLB_ENTRIES	4
 #define	SH_N_UTLB_ENTRIES	64
 
+/*  An instruction with an invalid encoding; used for software
+    emulation of PROM calls within GXemul:  */
 #define	SH_INVALID_INSTR	0x00fb
 
 
@@ -228,13 +228,7 @@ void sh_update_translation_table(struct cpu *cpu, uint64_t vaddr_page,
 	unsigned char *host_page, int writeflag, uint64_t paddr_page);
 void sh_invalidate_translation_caches(struct cpu *cpu, uint64_t, int);
 void sh_invalidate_code_translation(struct cpu *cpu, uint64_t, int);
-int sh32_run_instr(struct cpu *cpu);
-void sh32_update_translation_table(struct cpu *cpu, uint64_t vaddr_page,
-	unsigned char *host_page, int writeflag, uint64_t paddr_page);
-void sh32_invalidate_translation_caches(struct cpu *cpu, uint64_t, int);
-void sh32_invalidate_code_translation(struct cpu *cpu, uint64_t, int);
 void sh_init_64bit_dummy_tables(struct cpu *cpu);
-void sh_timer_sample_tick(struct timer *, void *);
 int sh_memory_rw(struct cpu *cpu, struct memory *mem, uint64_t vaddr,
 	unsigned char *data, size_t len, int writeflag, int cache_flags);
 int sh_cpu_family_init(struct cpu_family *);
