@@ -2,7 +2,7 @@
 #define	CPU_SPARC_H
 
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,14 +28,13 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_sparc.h,v 1.48 2007/06/07 15:36:25 debug Exp $
+ *  $Id: cpu_sparc.h,v 1.49.2.1 2008/01/18 19:12:32 debug Exp $
  */
 
 #include "misc.h"
 
 
 struct cpu_family;
-struct timer;
 
 
 /*  SPARC CPU types:  */
@@ -350,7 +349,6 @@ void sparc32_update_translation_table(struct cpu *cpu, uint64_t vaddr_page,
 void sparc32_invalidate_translation_caches(struct cpu *cpu, uint64_t, int);
 void sparc32_invalidate_code_translation(struct cpu *cpu, uint64_t, int);
 void sparc_init_64bit_dummy_tables(struct cpu *cpu);
-void sparc_timer_sample_tick(struct timer *, void *);
 int sparc_memory_rw(struct cpu *cpu, struct memory *mem, uint64_t vaddr,
 	unsigned char *data, size_t len, int writeflag, int cache_flags);
 int sparc_cpu_family_init(struct cpu_family *);
