@@ -2,7 +2,7 @@
 #define	MACHINE_H
 
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,7 +28,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: machine.h,v 1.179 2007/06/15 17:02:39 debug Exp $
+ *  $Id: machine.h,v 1.182.2.1 2008/01/18 19:12:32 debug Exp $
  */
 
 #include <sys/types.h>
@@ -63,6 +63,13 @@ struct breakpoints {
 	uint64_t	*addr;
 };
 
+struct statistics {
+	char	*filename;
+	FILE	*file;
+	int	enabled;
+	char	*fields;		/*  "vpi" etc.  */
+};
+
 struct tick_functions {
 	int	n_entries;
 
@@ -86,6 +93,10 @@ struct x11_md {
 	struct fb_window **fb_windows;
 };
 
+
+/*
+ *  The machine struct:
+ */
 struct machine {
 	/*  Pointer back to the emul struct we are in:  */
 	struct emul *emul;
@@ -96,7 +107,7 @@ struct machine {
 	/*  Name as choosen by the user:  */
 	char	*name;
 
-	/*  Full "path" to the machine, e.g. "emul[0].machine[0]":  */
+	/*  Full "path" to the machine, e.g. "machine[0]":  */
 	char	*path;
 
 	int	arch;			/*  ARCH_MIPS, ARCH_PPC, ..  */
@@ -166,10 +177,7 @@ struct machine {
 	int	n_gfx_cards;
 
 	/*  Instruction statistics:  */
-	char	*statistics_filename;
-	FILE	*statistics_file;
-	int	statistics_enabled;
-	char	*statistics_fields;	/*  "vpi" etc.  */
+	struct statistics statistics;
 
 	/*  X11/framebuffer stuff (per machine):  */
 	struct x11_md x11_md;
@@ -203,6 +211,7 @@ struct machine {
 #define	ARCH_ARM		5
 #define	ARCH_SH			6
 #define	ARCH_M88K		7
+#define	ARCH_M32R		8
 
 /*  MIPS:  */
 #define	MACHINE_BAREMIPS	1000
@@ -257,6 +266,10 @@ struct machine {
 #define	MACHINE_TESTM88K	7001
 #define	MACHINE_MVME88K		7002
 
+/*  M32R:  */
+#define	MACHINE_BAREM32R	8000
+#define	MACHINE_TESTM32R	8001
+
 /*  Other "pseudo"-machines:  */
 #define	MACHINE_NONE		0
 #define	MACHINE_USERLAND	100000
