@@ -2,7 +2,7 @@
 #define	MISC_H
 
 /*
- *  Copyright (C) 2003-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2003-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,7 +28,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: misc.h,v 1.257 2007/06/15 17:12:31 debug Exp $
+ *  $Id: misc.h,v 1.259.2.1 2008/01/18 19:12:32 debug Exp $
  *
  *  Misc. definitions for gxemul.
  */
@@ -105,6 +105,10 @@ static void *no_map_anon_mmap(void *addr, size_t len, int prot, int flags,
 #endif
 
 
+/*  tmp dir to use if the TMPDIR environment variable isn't set:  */
+#define	DEFAULT_TMP_DIR		"/tmp"
+
+
 struct cpu;
 struct emul;
 struct machine;
@@ -167,9 +171,9 @@ struct memory;
 #define	FAILURE(error_msg)					{	\
 		char where_msg[400];					\
 		snprintf(where_msg, sizeof(where_msg),			\
-		    "%s, line %i, function '%s'\n",			\
+		    "%s, line %i, function %s().\n",			\
 		    __FILE__, __LINE__, __FUNCTION__);			\
-        	fprintf(stderr, "%s: %s\n", error_msg, where_msg);	\
+        	fprintf(stderr, "\n%s, in %s\n", error_msg, where_msg);	\
 		exit(1);						\
 	}
 
@@ -179,7 +183,7 @@ struct memory;
 		char where_msg[400];					\
 		snprintf(where_msg, sizeof(where_msg),			\
 		    "%s, line %i\n", __FILE__, __LINE__);		\
-        	fprintf(stderr, "%s: %s\n", error_msg, where_msg);	\
+        	fprintf(stderr, "\n%s, in %s.\n", error_msg, where_msg);\
 		exit(1);						\
 	}
 
