@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2003-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: memory.c,v 1.204 2007/06/15 17:02:38 debug Exp $
+ *  $Id: memory.c,v 1.206.2.2 2008/01/18 19:12:24 debug Exp $
  *
  *  Functions for handling the memory of an emulated machine.
  */
@@ -440,7 +440,7 @@ void memory_device_register(struct memory *mem, const char *device_name,
 		fprintf(stderr, "memory_device_register():"
 		    " dyntrans_data not aligned correctly (%p)\n",
 		    dyntrans_data);
-		exit(1);
+		abort();
 	}
 
 	mem->devices[newi].dyntrans_write_low = (uint64_t)-1;
@@ -488,7 +488,7 @@ void memory_device_remove(struct memory *mem, int i)
 
 #define MEMORY_RW	userland_memory_rw
 #define MEM_USERLAND
-#include "memory_rw.c"
+#include "cpus/memory_rw.c"
 #undef MEM_USERLAND
 #undef MEMORY_RW
 
@@ -638,7 +638,7 @@ void memory_warn_about_unimplemented_addr(struct cpu *cpu, struct memory *mem,
 		debug("} ");
 	}
 
-	fatal("paddr=0x%llx >= physical_max; pc=", (long long)paddr);
+	fatal("paddr=0x%"PRIx64" >= physical_max; pc=", paddr);
 	if (cpu->is_32bit)
 		fatal("0x%08"PRIx32, (uint32_t) old_pc);
 	else
