@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2004-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: net.c,v 1.10 2007/06/15 17:02:39 debug Exp $
+ *  $Id: net.c,v 1.12.2.1 2008/01/18 19:12:33 debug Exp $
  *
  *  Emulated network.
  *
@@ -658,33 +658,33 @@ void net_dumpinfo(struct net *net)
 	int iadd = DEBUG_INDENTATION;
 	struct remote_net *rnp;
 
-	debug("net: simulating ");
+	debug("net:\n");
 
+	debug_indentation(iadd);
+
+	debug("simulated network: ");
 	net_debugaddr(&net->netmask_ipv4, NET_ADDR_IPV4);
 	debug("/%i", net->netmask_ipv4_len);
 
 	debug(" (max outgoing: TCP=%i, UDP=%i)\n",
 	    MAX_TCP_CONNECTIONS, MAX_UDP_CONNECTIONS);
 
-	debug_indentation(iadd);
-
-	debug("simulated gateway: ");
+	debug("simulated gateway+nameserver: ");
 	net_debugaddr(&net->gateway_ipv4_addr, NET_ADDR_IPV4);
 	debug(" (");
 	net_debugaddr(&net->gateway_ethernet_addr, NET_ADDR_ETHERNET);
 	debug(")\n");
 
-	debug_indentation(iadd);
 	if (!net->nameserver_known) {
-		debug("(could not determine nameserver)");
+		debug("(could not determine nameserver)\n");
 	} else {
-		debug("using nameserver ");
+		debug("simulated nameserver uses real nameserver ");
 		net_debugaddr(&net->nameserver_ipv4, NET_ADDR_IPV4);
+		debug("\n");
 	}
+
 	if (net->domain_name != NULL && net->domain_name[0])
-		debug(", domain \"%s\"", net->domain_name);
-	debug("\n");
-	debug_indentation(-iadd);
+		debug("domain: %s\n", net->domain_name);
 
 	rnp = net->remote_nets;
 	if (net->local_port != 0)
