@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2003-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,9 +25,9 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: arcbios.c,v 1.16 2007/06/15 17:02:40 debug Exp $
+ *  $Id: arcbios.c,v 1.19.2.1 2008/01/18 19:12:33 debug Exp $
  *
- *  ARCBIOS emulation.
+ *  COMMENT: ARCBIOS emulation
  */
 
 #include <stdio.h>
@@ -1531,7 +1531,7 @@ int arcbios_emul(struct cpu *cpu)
 		break;
 	case 0x64:  /*  Read(handle, void *buf, length, uint32_t *count)  */
 		if (cpu->cd.mips.gpr[MIPS_GPR_A0] == ARCBIOS_STDIN) {
-			int i, nread = 0;
+			int i, nread = 0, a2;
 			/*
 			 *  Before going into the loop, make sure stdout
 			 *  is flushed.  If we're using an X11 VGA console,
@@ -1544,8 +1544,8 @@ int arcbios_emul(struct cpu *cpu)
 				machine->tick_functions.f[i](cpu,
 				    machine->tick_functions.extra[i]);
 
-			for (i=0; i<(int32_t)cpu->cd.mips.gpr[MIPS_GPR_A2];
-			    i++) {
+			a2 = cpu->cd.mips.gpr[MIPS_GPR_A2];
+			for (i=0; i<a2; i++) {
 				int x;
 				unsigned char ch;
 
@@ -2449,11 +2449,7 @@ void arcbios_init(struct machine *machine, int is64bit, uint64_t sgi_ram_offset,
 		machine->md.arc->console_curx = 0;
 		machine->md.arc->console_cury = 0;
 
-		arcbios_putstring(cpu, "GXemul");
-#ifdef VERSION
-		arcbios_putstring(cpu, " "VERSION);
-#endif
-		arcbios_putstring(cpu, "   ARCBIOS emulation\n");
+		arcbios_putstring(cpu, "GXemul "VERSION"  ARCBIOS emulation\n");
 
 		snprintf(tmpstr, sizeof(tmpstr), "%i cpu%s (%s), %i MB "
 		    "memory\n\n", machine->ncpus, machine->ncpus > 1? "s" : "",
